
#if !defined(STLSOFT_INCL_STLSOFT_HPP_STRING_VIEW)
# error This file cannot be directly included, and should only be included within stlsoft/string_view.hpp
#endif /* !STLSOFT_INCL_STLSOFT_HPP_STRING_VIEW */

#if !defined(STLSOFT_UNITTEST)
# error This file cannot be included when not unit-testing STLSoft
#endif /* !STLSOFT_UNITTEST */

namespace unittest
{
# if !defined(STLSOFT_COMPILER_IS_MWERKS) || \
     (__MWERKS__ & 0xFF00) >= 0x3000
    namespace
    {
        ss_bool_t test_stlsoft_string_view(unittest_reporter *r)
        {
            ss_bool_t               bSuccess    =   true;

            unittest_initialiser    init(r, "STLSoft", "string_view", __FILE__);

            typedef stlsoft_ns_qual(basic_string_view)< char
                                                    ,   char_traits<char>
                                                    ,   allocator_selector<char>::allocator_type
                                                    >       seg_string_t;

            char const      s[] = "Hello Natty!";

            if(!seg_string_t().empty())
            {
                r->report("Default construction and/or != comparison failed", __LINE__);
                bSuccess = false;
            }

            if(seg_string_t() != seg_string_t())
            {
                r->report("Default construction and/or != comparison failed", __LINE__);
                bSuccess = false;
            }
            seg_string_t    ss(s, stlsoft_num_elements(s) - 1);
            seg_string_t    ss1(&s[6], 6);
            seg_string_t    ss2(&s[0], 5);

            if(ss1 <= ss2)
            {
                r->report("<= comparison failed", __LINE__);
                bSuccess = false;
            }
            if(ss2 > ss1)
            {
                r->report("> comparison failed", __LINE__);
                bSuccess = false;
            }

            if(0 != seg_string_t("abc", 3).compare("abc"))
            {
                r->report("compare(s) failed", __LINE__);
                bSuccess = false;
            }

            if(0 != seg_string_t("abcdef", 3).compare(0, 3, "abc"))
            {
                r->report("compare(p, cch, s) failed", __LINE__);
                bSuccess = false;
            }

            if(0 != seg_string_t("Well done Matty!", 16).compare(11, 5, ss, 7, 5))
            {
                r->report("compare(p, cch, r, rp, rn) failed", __LINE__);
                bSuccess = false;
            }

#ifdef __STLSOFT_CF_STATIC_ARRAY_SIZE_DETERMINATION_SUPPORT
            seg_string_t    ss3(s);

            if(ss3 != s)
            {
                r->report("array[] constructor failed", __LINE__);
                bSuccess = false;
            }
#endif /* __STLSOFT_CF_STATIC_ARRAY_SIZE_DETERMINATION_SUPPORT */

            return bSuccess;
        }

        unittest_registrar    unittest_stlsoft_string_view(test_stlsoft_string_view);
    } // anonymous namespace
# endif /* compiler */

} // namespace unittest
